@@ -183,7 +183,7 @@ class File(object):
                 'headers': headers,
                 'http_response': http_response,
             })
-            content = http_response.content
-            print(f'Error occurred when put object: {err}, {content}, {traceback.format_exc()}')
+            # content = http_response.content
+            # print(f'Error occurred when put object: {err}, {content}, {traceback.format_exc()}')
             return False
         return True
